calc.acceptfreq: Calculate apparent acceptance frequency of time-dependent parameter
Description
This function calculates the apparent acceptance frequency from a potentially thinned Markov chain sample.
Usage
calc.acceptfreq(x, n.burnin)
Value
list two-column matrices with time and apparent acceptance frequencies
Arguments
- x
results from the function infer.timedeppar of class timedeppar.
- n.burnin
number of (unthinned) burnin points of the Markov chain to omit from analysis.